@@ -1,6 +1,5 @@
 package ExtUtils::XSpp::Node::Class;
 use strict;
-use warnings;
 use base 'ExtUtils::XSpp::Node::Package';
 
 =head1 NAME
@@ -31,33 +30,16 @@ C<methods> can be a reference to an array of methods
 (L<ExtUtils::XSpp::Node::Method>) of the class,
 and C<base_classes>, a reference to an array of
 base classes (C<ExtUtils::XSpp::Node::Class> objects).
-C<catch> may be a list of exception names that all
-methods in the class handle.
 
 =cut
 
-# internal list of all the non-empty class objects, either defined by the
-# parser or created by plugins; does not include dummy base class objects
-my %all_classes;
-
 sub init {
   my $this = shift;
   my %args = @_;
 
   $this->SUPER::init( @_ );
-  $this->{METHODS} = [];
+  $this->{METHODS} = $args{methods} || [];
   $this->{BASE_CLASSES} = $args{base_classes} || [];
-  $this->add_methods( @{$args{methods}} ) if $args{methods};
-  $this->{CATCH}     = $args{catch};
-  $this->{CONDITION} = $args{condition};
-
-  $all_classes{$this->cpp_name} = $this unless $this->empty;
-
-  # TODO check the Perl name of the base class?
-  foreach my $base ( @{$this->base_classes} ) {
-    $base = $all_classes{$base->cpp_name}
-        if $all_classes{$base->cpp_name};
-  }
 }
 
 =head2 add_methods
@@ -84,9 +66,7 @@ sub add_methods {
       if( $meth->isa( 'ExtUtils::XSpp::Node::Method' ) ) {
           $meth->{CLASS} = $this;
           $meth->{ACCESS} = $access;
-          $meth->add_exception_handlers( @{$this->{CATCH} || []} );
           $meth->resolve_typemaps;
-          $meth->resolve_exceptions;
       } elsif( $meth->isa( 'ExtUtils::XSpp::Node::Access' ) ) {
           $access = $meth->access;
           next;
@@ -94,15 +74,6 @@ sub add_methods {
       # FIXME: Should there be else{croak}?
       push @{$this->{METHODS}}, $meth;
   }
-
-  $all_classes{$this->cpp_name} = $this unless $this->empty;
-}
-
-sub delete_methods {
-    my( $this, @methods ) = @_;
-    my %methods = map { $_ => 1 } @methods;
-
-    $this->{METHODS} = [ grep !$methods{$_}, @{$this->{METHODS}} ];
 }
 
 sub print {
@@ -111,7 +82,6 @@ sub print {
   my $out = $this->SUPER::print( $state );
 
   foreach my $m ( @{$this->methods} ) {
-    next if $m->can( 'access' ) && $m->access ne 'public';
     $out .= $m->print( $state );
   }
 
@@ -122,10 +92,6 @@ sub print {
       $out .= <<EOT;
 BOOT:
     {
-EOT
-
-      $out .= '#ifdef ' . $this->condition . "\n" if $this->condition;
-      $out .= <<EOT;
         AV* isa = get_av( "${class}::ISA", 1 );
 EOT
 
@@ -138,7 +104,6 @@ EOT
     }
 
       # close block in BOOT
-      $out .= '#endif // ' . $this->condition . "\n" if $this->condition;
       $out .= <<EOT;
     } // blank line here is important
 
@@ -160,14 +125,9 @@ Each of the methods is an C<ExtUtils::XSpp::Node::Method>
 Returns the internal reference to the array of base classes of
 this class.
 
-If the base classes have been defined in the same file, these are the
-complete class objects including method definitions, otherwise only
-the C++ and Perl name of the class are available as attributes.
-
 =cut
 
 sub methods { $_[0]->{METHODS} }
 sub base_classes { $_[0]->{BASE_CLASSES} }
-sub empty { !$_[0]->methods || !@{$_[0]->methods} }
 
-1;
+1;
\ No newline at end of file
